@@ -60,15 +60,10 @@ class Scheduler(Process):
     """A Remote Dask Scheduler controlled via HTCondor
     Parameters
     ----------
-    address: str
-        The hostname where we should run this worker
-    connect_options: dict
-        kwargs to be passed to asyncssh connections
-    remote_python: str
-        Path to Python on remote node to run this scheduler.
-    kwargs: dict
-        These will be passed through the dask-scheduler CLI to the
-        dask.distributed.Scheduler class
+    sched_port: int
+        The port to bind for scheduler
+    dashboard_port: int
+        The port to bind for dask dasahboard
     """
 
     def __init__(self, sched_port=8989, dashboard_port=8787):
@@ -83,6 +78,10 @@ class Scheduler(Process):
         self.dash_port = dashboard_port
 
         self.token = os.environ.get("JUPYTERHUB_API_TOKEN")
+        self.refresh_token = os.environ.get("REFRESH_TOKEN")
+        self.iam_server = os.environ.get("IAM_SERVER")
+        self.client_id = os.environ.get("IAM_CLIENT_ID")
+        self.client_secret = os.environ.get("IAM_CLIENT_SECRET")
         super().__init__()
 
     def scale(self, n=0, memory=None, cores=None):
@@ -126,6 +125,10 @@ class Scheduler(Process):
                             token=self.token,
                             sched_port=self.sched_port,
                             dash_port=self.dash_port,
+                            refresh_token=self.refresh_token,
+                            iam_server=self.iam_server,
+                            client_id=self.client_id,
+                            client_secret=self.client_secret,
                         )
                     )
 
